TestDevice class

Constructors

TestDevice({required Size size, required String name, double devicePixelRatio = 1.0, EdgeInsets safeArea = const EdgeInsets.all(0)})

Properties

brightness → Brightness
brightness specify platform brightness
finalinherited
devicePixelRatio → double
devicePixelRatio specify device Pixel Ratio
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
name specify device name. Ex: Phone, Tablet, Watch
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeArea → EdgeInsets
safeArea specify insets to define a safe area
finalinherited
size → Size
size specify device screen size. Ex: Size(1366, 1024))
finalinherited
textScale → double
textScale specify custom text scale
finalinherited

Methods

copyWith({Size? size, double? devicePixelRatio, String? name, double? textScale, Brightness? brightness, EdgeInsets? safeArea}) → Device
copyWith convenience function for Device modification
inherited
dark() → Device
dark convenience method to copy the current device and apply dark theme
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited